Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildConfiguration ¶
type BuildConfiguration struct {
Commands []string `yaml:"commands"` // Command is the command to run
Environment map[string]string `yaml:"environment"` // A list of environment variables to add to the env of the forked process
Label string `yaml:"label" validate:"required"` // Label is the name of the build configuration
Dependencies []string `yaml:"dependencies"` // A list of dependencies to other build configurations
Parallel bool `yaml:"parallel"` // Parallel determines whether build configuration is allowed to run in parallel
// contains filtered or unexported fields
}
BuildConfiguration contains information about how to build the software
func (*BuildConfiguration) SetDirectory ¶
func (configuration *BuildConfiguration) SetDirectory(path string)
SetDirectory stores the directory of the build configuration
func (*BuildConfiguration) String ¶
func (configuration *BuildConfiguration) String() string
The String method is used to print values passed as an operand to any format that accepts a string or to an unformatted printer such as Print.
type MonoBuild ¶
type MonoBuild struct {
DisableParallelism bool // DisableParallelism can be used to run build independently of markers
MarkerName string // MarkerName is the name of the file with the build configuration
// contains filtered or unexported fields
}
MonoBuild contains all data required to run the program
func NewMonoBuild ¶
NewMonoBuild creates an empty mono build runner
func (*MonoBuild) AddBuildConfiguration ¶
func (c *MonoBuild) AddBuildConfiguration(configuration *BuildConfiguration) error
AddBuildConfiguration allows adding a build configuration from code
func (*MonoBuild) LoadConfigurations ¶
LoadConfigurations scans the directory tree for build configurations
type MonobuildEnviron ¶
type MonobuildEnviron struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.